%==========================================================
% Mercury Matlab Version 1.0.1
% Written by Dae-Hung Kang, CU-NEES
% Copyright 2009, CU-NEES
% Written  : September 2009.
% File name: Ex01.m
%==========================================================

%----------------------------------------------------------
% Description
% 1. Static and transient analysis
% 2. Muliti nodal forces
% 3. Linear method
% 4. Simple 2D truss element
% 5. General section
% 6. Elastic material
%----------------------------------------------------------
% pp. 374, 9-22
% Structural Analysis Sixth Edition (2006) by R.C. Hibbeler
% Published by Pearson Prentice Hall
% A-36 Steel member, Cross-sectional area = 400mm^2, E=200GPa=200kN/mm^2
%----------------------------------------------------------
% Select type of analysis.
% AnalysisTyep = 1: Static analysis
% AnalysisType = 2: Transient analysis
AnalysisType = 2;
%----------------------------------------------------------
% Preface
Unit    = {'kN', 'mm'};
StrMode = {2, 2};
%----------------------------------------------------------
% Control block
Iteration = {'static',    { {'Linear'} } ;
             'transient', { {'Linear'} };
            };
if (AnalysisType == 2)
    Integration = {'Newmark', 0, 1/4, 1/2, 0, 0};
    eigens      = {0.02, 0.02};
end
%----------------------------------------------------------
% Geometry block
nodcoord   = {1,    0, 0;
              2, 1500, 0;
              3, 3000, 0;
              4, 1500, 2000;
              5, 3000, 2000};
constraint = {3, 1, 1;
              5, 1, 1};
%----------------------------------------------------------
% Element block
elements = { {1, 'Simple2DTruss', 1, 2, 1};
             {2, 'Simple2DTruss', 2, 3, 1};
             {3, 'Simple2DTruss', 1, 4, 1};
             {4, 'Simple2DTruss', 2, 4, 1};
             {5, 'Simple2DTruss', 3, 4, 1};
             {6, 'Simple2DTruss', 4, 5, 1} };
%----------------------------------------------------------
% Section block
sections = { 1, 'General', {1, 400, 0, 0, 0} };
%----------------------------------------------------------
% Material block
materials = { {1, 'Elastic', 200, 0, 7850*10^-9} };
%----------------------------------------------------------
% Force block
if (AnalysisType == 1)
    forces = { 1, 'Static', {'NodalForces', {1, 2, -30;
                                             2, 2, -20} } };
elseif (AnalysisType == 2)
    ga = load('ElCentro_g_0_01_Matlab.txt');
    nga = size(ga, 1);
    for i = 1:nga
        groundacceleration{i,1} = ga(i,1);
        groundacceleration{i,2} = ga(i,2);
        groundacceleration{i,3} = ga(i,3);
    end
    forces = { 1, 'Static', {'NodalForces', {1, 2, 0} };
               2, 'Acceleration', {9810, groundacceleration} };
end
%----------------------------------------------------------
outputdata = {'NodalDisplacement','ND.txt', {1, 2, 3};
              'NodalVelocity','NV.txt', {1, 2};
              'NodalAcceleration', 'NA.txt', {1,2,3,4,5};
              'NodalForce','NF.txt', {1};
              'SectionAxialForce', 'SAF.txt', {1, 1;
                                               1, 2};
              'SectionAxialDeformation', 'SAD.txt', {1, 1}
              'SectionMoment', 'SM.txt', {1, 1;
                                          1, 2}; 
              'SectionCurvature', 'SC.txt', {1, 2;};
              'UniaxialStressStrain', 'USS.txt', {1, 1, 1;
                                                 1, 2, 2}};